#!/bin/env/python3

import subprocess
import os
import fnmatch
from ac_datasets import AC_datasets
from datetime import datetime, timedelta
import pandas as pd
from pathlib import Path

def du(path: str) -> int:
    size = sum(p.stat().st_size for p in Path(path).rglob('*'))
    return size

def filesize(size: int) -> str:
    orig_size = size
    for unit in ("B", "K", "M", "G", "T"):
        if size < 1024:
            break
        size /= 1024
    print("{}{}".format(round(size, 2), unit))
    return orig_size
    

def missing_data(path, start_date, end_date, num_files, suffix):
    """shows missing data in a path from a start date to end date"""
    # End date to yesterday if operational dateset
    if end_date == "operational":
        end_date = datetime.today() + timedelta(days=-1)
    if isinstance(start_date, str):
        start_date = pd.to_datetime(start_date, format="%Y%m%d")
    if isinstance(end_date, str):
        end_date = pd.to_datetime(end_date, format="%Y%m%d")

    dates = pd.date_range(start_date, end_date).strftime("%Y%m%d")
    years = list(pd.date_range(start_date, end_date).strftime("%Y"))
    # Check for the whole year
    for year in sorted(set(years)):
        
        print("CHECKING YEAR {}".format(year))
        print("================================")
        max_files = years.count(year)
        year_dates = [date for date in dates if year in date[:4]]
        missing_dates = []
        for date in year_dates:

            # This works for single files
            #search_path = path 

            # This works for directory type files
            if suffix == "":
                dir_path = path + date
            else:
                dir_path = path + date + suffix
            try:
                count = len(fnmatch.filter(os.listdir(dir_path), '*.*'))
            except FileNotFoundError:
                count = 0
            if count != num_files:
                missing_dates.append(date)
        num_of_missing_dates = max_files - len(missing_dates)
        print("FILES AVAILABLE FOR THAT YEAR {}/{}".format(num_of_missing_dates, max_files))
        if missing_dates:
            print("DATES WITH MISSING FILES {}".format(missing_dates))
        print("================================")
        





if __name__ == "__main__":
    size = 0
    for dataset, info in AC_datasets.items():
        print("DATASET")
        print(dataset)
        path = info["path"]
        start_date = info["start_date"]
        end_date = info["end_date"]
        num_files = info["numfilesperday"]
        suffix = info["suffix"]

        size += filesize(du(path))
        missing_data(path, start_date, end_date, num_files, suffix)
    
    print("Size of all AC datasets")
    filesize(size)

